@@ -12,6 +12,10 @@ TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), "templates")
 
 
 def get_template(name):
+    """
+    Fungsi untuk mendapatkan base template.
+    """
+
     t = os.path.join(TEMPLATE_DIR, name)
     if not os.path.isdir(t):
         raise ZemfrogTemplateNotFound("unknown template %r" % name)
@@ -20,18 +24,30 @@ def get_template(name):
 
 
 def copy_template(name, dst):
+    """
+    Fungsi untuk menyalin template.
+    """
+
     t = get_template(name)
     copy_tree(t, dst)
 
 
 def import_attr(module):
+    """
+    Fungsi untuk mengambil atribut pada modul.
+    """
+
     pkg, name = module.rsplit(".", 1)
     mod = import_module(pkg)
     return getattr(mod, name)
 
 
 def search_model(name):
-    for src, models in current_app.models:
+    """
+    Fungsi untuk mendapatkan lokasi model.
+    """
+
+    for src, models in current_app.models.items():
         if name in models:
             return src
 
@@ -39,6 +55,10 @@ def search_model(name):
 
 
 def get_models(mod):
+    """
+    Fungsi untuk mendapatkan semua model ORM pada modul.
+    """
+
     models = []
     childs = dir(mod)
     for c in childs:
@@ -54,26 +74,46 @@ def get_models(mod):
 
 
 def db_add(db, model):
+    """
+    Fungsi untuk menambahkan data ke database.
+    """
+
     db.session.add(model)
     db_commit(db)
 
 
 def db_delete(db, model):
+    """
+    Fungsi untuk menghapus data di database.
+    """
+
     db.session.delete(model)
     db_commit(db)
 
 
 def db_update(db, model, **kwds):
+    """
+    Fungsi untuk memperbaharui data di database.
+    """
+
     for k, v in kwds.items():
         setattr(model, k, v)
     db_commit(db)
 
 
 def db_commit(db):
+    """
+    Fungsi untuk menyimpan data ke database.
+    """
+
     db.session.commit()
 
 
 def get_mail_template(name, **context):
+    """
+    Fungsi untuk mendapatkan email template.
+    """
+
     tmp_src = os.path.join("mail", name)
     if not os.path.isfile(tmp_src):
         raise ZemfrogTemplateNotFound("email template %r tidak ditemukan" % name)
