@@ -1,32 +1,38 @@
-from zemfrog.decorators import is_json_request, json_renderer
+from zemfrog.decorators import auto_status_code
 from zemfrog.helper import db_add, db_delete, db_update
-from flask import request
+from zemfrog.models import DefaultResponseSchema
+from flask_apispec import marshal_with, use_kwargs
 from extensions.sqlalchemy import db
+from extensions.marshmallow import ma
 from ${src_model} import ${name}
 from ${src_schema} import ${name}Schema
 
+class UpdateSchema(${name}Schema):
+    __update__ = ma.Nested(${name}Schema)
+
 schema = ${name}Schema()
 
-@json_renderer
+@marshal_with(${name}Schema(many=True), 200)
 def get():
     """
     Read all data.
     """
 
     data = ${name}.query.all()
-    return schema.dump(data, many=True)
+    return data
 
-@is_json_request
-@json_renderer
-def add():
+@use_kwargs(schema)
+@marshal_with(DefaultResponseSchema, 200)
+@marshal_with(DefaultResponseSchema, 403)
+@auto_status_code
+def add(**json):
     """
     Add data.
     """
 
-    json = request.get_json()
     found = ${name}.query.filter_by(**json).first()
     if not found:
-        model = schema.load(json)
+        model = ${name}(**json)
         db_add(db, model)
         status_code = 200
         reason = "Data berhasil ditambahkan."
@@ -40,14 +46,16 @@ def add():
         "reason": reason
     }
 
-@is_json_request
-@json_renderer
-def update():
+@use_kwargs(UpdateSchema)
+@marshal_with(DefaultResponseSchema, 200)
+@marshal_with(DefaultResponseSchema, 404)
+@marshal_with(DefaultResponseSchema, 403)
+@auto_status_code
+def update(**json):
     """
     Update data.
     """
 
-    json = request.get_json()
     new_data = json.pop("__update__", None)
     if new_data and isinstance(new_data, dict):
         model = ${name}.query.filter_by(**json).first()
@@ -69,14 +77,15 @@ def update():
         "reason": reason
     }
 
-@is_json_request
-@json_renderer
-def delete():
+@use_kwargs(schema)
+@marshal_with(DefaultResponseSchema, 200)
+@marshal_with(DefaultResponseSchema, 404)
+@auto_status_code
+def delete(**json):
     """
     Delete data.
     """
 
-    json = request.get_json()
     model = ${name}.query.filter_by(**json).first()
     if model:
         db_delete(db, model)
@@ -92,6 +101,8 @@ def delete():
         "reason": reason
     }
 
+
+docs = {"tags": ["${name}"]}
 endpoint = "${url_prefix}"
 url_prefix = "/${url_prefix}"
 routes = [
